==> zio-aws-rds_3-5.17.155.1-sources.jar: zio/aws/rds/model/ResetDbParameterGroupRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ResetDbParameterGroupRequest(
    dbParameterGroupName: String,
    resetAllParameters: scala.Option[Boolean] = None,
    parameters: scala.Option[Iterable[zio.aws.rds.model.Parameter]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest = {
    import ResetDbParameterGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
      .builder()
      .dbParameterGroupName(dbParameterGroupName: java.lang.String)
      .optionallyWith(
        resetAllParameters.map(value => value: java.lang.Boolean)
      )(_.resetAllParameters)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly =
    zio.aws.rds.model.ResetDbParameterGroupRequest.wrap(buildAwsValue())
}
object ResetDbParameterGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ResetDbParameterGroupRequest =
      zio.aws.rds.model.ResetDbParameterGroupRequest(
        dbParameterGroupName,
        resetAllParameters.map(value => value),
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def dbParameterGroupName: String
    def resetAllParameters: scala.Option[Boolean]
    def parameters: scala.Option[List[zio.aws.rds.model.Parameter.ReadOnly]]
    def getDbParameterGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbParameterGroupName)
    def getResetAllParameters: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("resetAllParameters", resetAllParameters)
    def getParameters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Parameter.ReadOnly]] =
      AwsError.unwrapOptionField("parameters", parameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ) extends zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly {
    override val dbParameterGroupName: String =
      impl.dbParameterGroupName(): String
    override val resetAllParameters: scala.Option[Boolean] =
      scala.Option(impl.resetAllParameters()).map(value => value: Boolean)
    override val parameters
        : scala.Option[List[zio.aws.rds.model.Parameter.ReadOnly]] = scala
      .Option(impl.parameters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Parameter.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ): zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.195.2-sources.jar: zio/aws/rds/model/ResetDbParameterGroupRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ResetDbParameterGroupRequest(
    dbParameterGroupName: String,
    resetAllParameters: Optional[Boolean] = Optional.Absent,
    parameters: Optional[Iterable[zio.aws.rds.model.Parameter]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest = {
    import ResetDbParameterGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
      .builder()
      .dbParameterGroupName(dbParameterGroupName: java.lang.String)
      .optionallyWith(
        resetAllParameters.map(value => value: java.lang.Boolean)
      )(_.resetAllParameters)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly =
    zio.aws.rds.model.ResetDbParameterGroupRequest.wrap(buildAwsValue())
}
object ResetDbParameterGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ResetDbParameterGroupRequest =
      zio.aws.rds.model.ResetDbParameterGroupRequest(
        dbParameterGroupName,
        resetAllParameters.map(value => value),
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def dbParameterGroupName: String
    def resetAllParameters: Optional[Boolean]
    def parameters: Optional[List[zio.aws.rds.model.Parameter.ReadOnly]]
    def getDbParameterGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbParameterGroupName)
    def getResetAllParameters: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("resetAllParameters", resetAllParameters)
    def getParameters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Parameter.ReadOnly]] =
      AwsError.unwrapOptionField("parameters", parameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ) extends zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly {
    override val dbParameterGroupName: String =
      impl.dbParameterGroupName(): String
    override val resetAllParameters: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.resetAllParameters())
      .map(value => value: Boolean)
    override val parameters
        : Optional[List[zio.aws.rds.model.Parameter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.Parameter.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ResetDbParameterGroupRequest
  ): zio.aws.rds.model.ResetDbParameterGroupRequest.ReadOnly = new Wrapper(impl)
}
